diff apiexample.c @ 71:79be2c581c01 libavcodec

changed opendivx to mpeg4
author glantau
date Wed, 15 Aug 2001 13:12:23 +0000
parents 986e461dc072
children 44a1dab0205c
line wrap: on
line diff
--- a/apiexample.c	Wed Aug 15 13:11:31 2001 +0000
+++ b/apiexample.c	Wed Aug 15 13:12:23 2001 +0000
@@ -292,7 +292,7 @@
     /* put default values */
     memset(c, 0, sizeof(*c));
 
     /* for some codecs, such as msmpeg4 and opendivx, width and height
        MUST be initialized there because these info are not available
        in the bitstream */
 
@@ -320,9 +320,9 @@
            and this is the only method to use them because you cannot
            know the compressed data size before analysing it. 
 
-           BUT some other codecs (msmpeg4, opendivx) are inherently
-           frame based, so you must call them with all the data for
-           one frame exactly. You must also initialize 'width' and
+           BUT some other codecs (msmpeg4, mpeg4) are inherently frame
+           based, so you must call them with all the data for one
+           frame exactly. You must also initialize 'width' and
            'height' before initializing them. */
 
         /* NOTE2: some codecs allow the raw parameters (frame size,
@@ -292,7 +292,7 @@
     memset(c, 0, sizeof(*c));
 
-    /* for some codecs, such as msmpeg4 and opendivx, width and height
+    /* for some codecs, such as msmpeg4 and mpeg4, width and height
        MUST be initialized there because these info are not available
        in the bitstream */